#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chimera
version:              0.4.2.0
visibility:           public
id:                   chimera-0.4.2.0-3x3i7IPDnW8HKYtPkuxzoi
key:                  chimera-0.4.2.0-3x3i7IPDnW8HKYtPkuxzoi
license:              BSD-3-Clause
copyright:            2017-2019 Bodigrim
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/chimera#readme
synopsis:
    Lazy infinite streams with O(1) indexing and applications for memoization

description:
    There are plenty of memoizing libraries on Hackage, but they
    usually fall into two categories:

    * Store cache as a flat array, enabling us
    to obtain cached values in O(1) time, which is nice.
    The drawback is that one must specify the size
    of the array beforehand,
    limiting an interval of inputs,
    and actually allocate it at once.
    * Store cache as a lazy binary tree.
    Thanks to laziness, one can freely use the full range of inputs.
    The drawback is that obtaining values from a tree
    takes logarithmic time and is unfriendly to CPU cache,
    which kinda defeats the purpose.

    This package intends to tackle both issues,
    providing a data type '\''Chimera'\'' for
    lazy infinite compact streams with cache-friendly O(1) indexing.

    Additional features include:

    * memoization of recursive functions and recurrent sequences,
    * memoization of functions of several, possibly signed arguments,
    * efficient memoization of boolean predicates.

category:             Data
abi:                  bf2fc3a0b15de4b5b13418893c1f9277
exposed:              True
exposed-modules:
    Data.Chimera Data.Chimera.ContinuousMapping
    Data.Chimera.WheelMapping

hidden-modules:
    Data.Chimera.Compat Data.Chimera.FromIntegral Data.Chimera.Internal
    Data.Chimera.Memoize

import-dirs:          /usr/lib/ghc-9.6.6/site-local/chimera-0.4.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chimera-0.4.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chimera-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chimera
hs-libraries:         HSchimera-0.4.2.0-3x3i7IPDnW8HKYtPkuxzoi
depends:
    adjunctions-4.4.4-Cg0JLwPxse01lSKuEZWwy8 base-4.18.2.1
    distributive-0.6.3-7aYPGPHhVXd4FJqU4bakPh
    infinite-list-0.1.3-9pLkc9HuonCLKMdmBzCmek mtl-2.3.1
    primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5 transformers-0.6.1.0
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:   /usr/share/doc/haskell-chimera/html/chimera.haddock
haddock-html:         /usr/share/doc/haskell-chimera/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

